@@ -97,10 +97,29 @@ clearlooks_style_draw_flat_box (DRAW_ARGS)
 
 		cairo_destroy (cr);
 	}
-	else if (CLEARLOOKS_STYLE (style)->style == CL_STYLE_GLOSSY &&
+	else if (DETAIL ("tooltip"))
+	{
+		WidgetParameters params;
+		ClearlooksStyle  *clearlooks_style;
+		ClearlooksColors *colors;
+		cairo_t          *cr;
+
+		CHECK_ARGS
+		SANITIZE_SIZE
+
+		clearlooks_style = CLEARLOOKS_STYLE (style);
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		colors = &clearlooks_style->colors;
+		cr = ge_gdk_drawable_to_cairo (window, area);
+
+		STYLE_FUNCTION (draw_tooltip) (cr, colors, &params, x, y, width, height);
+
+		cairo_destroy (cr);
+	}
+	else if ((CLEARLOOKS_STYLE (style)->style == CL_STYLE_GLOSSY || CLEARLOOKS_STYLE (style)->style == CL_STYLE_GUMMY) &&
 	         ((DETAIL("checkbutton") || DETAIL("radiobutton")) && state_type == GTK_STATE_PRELIGHT))
 	{
-		/* XXX: Don't draw any check/radiobutton bg in GLOSSY mode. */
+		/* XXX: Don't draw any check/radiobutton bg in GLOSSY or GUMMY mode. */
 	}
 	else
 	{
@@ -174,7 +193,7 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 	{
 		CairoColor *border = (CairoColor*)&colors->shade[5];
 		cairo_rectangle (cr, x+0.5, y+0.5, width-1, height-1);
-		cairo_set_source_rgb (cr, border->r, border->g, border->b);
+		ge_cairo_set_color (cr, border);
 		cairo_set_line_width (cr, 1);
 		cairo_stroke (cr);
 	}
@@ -187,7 +206,7 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 		frame.gap_x  = -1;
 		frame.border = &colors->shade[5];
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		params.corners = CR_CORNER_NONE;
+		params.corners = CR_CORNER_ALL;
 		
 		STYLE_FUNCTION(draw_frame) (cr, colors, &params, &frame, x, y, width, height);
 	}
@@ -214,6 +233,7 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 	{
 		WidgetParameters params;
 		FrameParameters  frame;
+		int current_page, num_pages;
 		
 		frame.shadow    = shadow_type;
 		frame.gap_side  = gap_side;
@@ -223,9 +243,82 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
-		params.corners = CR_CORNER_NONE;
+		/* Modified from Aurora Engine
+		*** 
+		We need to fix the clip problem on first tab and rounded corners
+		Last Active tab could be buggied if the tabs cover more space then the notebook width
+		***
+		*/
+		current_page = gtk_notebook_get_current_page ((GtkNotebook *) widget);
+		num_pages = gtk_notebook_get_n_pages ((GtkNotebook *) widget);
+
+		if (frame.gap_side == CL_GAP_TOP) {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT;
+				/* params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT; */
+			}
+			else {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+		else if (frame.gap_side == CL_GAP_BOTTOM) {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT;
+				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT; */
+			}
+			else {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+		else if (frame.gap_side == CL_GAP_LEFT) {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_TOPRIGHT;
+				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT; */
+			}
+			else {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+		else {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT;
+				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT; */
+			}
+			else {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+
 		/* Fill the background with bg[NORMAL] */
-		cairo_rectangle (cr, x, y, width, height);
+		ge_cairo_rounded_rectangle (cr, x, y, width, height, params.radius, params.corners);
 		ge_cairo_set_color (cr, &colors->bg[GTK_STATE_NORMAL]);
 		cairo_fill (cr);
 		
@@ -321,8 +414,12 @@ clearlooks_style_draw_handle (DRAW_ARGS, GtkOrientation orientation)
 		/* Is this ever true? -Daniel */
 		if (GE_IS_TOOLBAR (widget) && shadow_type != GTK_SHADOW_NONE)
 		{
+			ToolbarParameters toolbar;
+
+			clearlooks_set_toolbar_parameters (&toolbar, widget, window, x, y);
+
 			cairo_save (cr);
-			STYLE_FUNCTION(draw_toolbar) (cr, colors, &params, x, y, width, height);
+			STYLE_FUNCTION(draw_toolbar) (cr, colors, &params, &toolbar, x, y, width, height);
 			cairo_restore (cr);
 		}
 		
@@ -353,8 +450,12 @@ clearlooks_style_draw_handle (DRAW_ARGS, GtkOrientation orientation)
 		/* Is this ever true? -Daniel */
 		if (GE_IS_TOOLBAR (widget) && shadow_type != GTK_SHADOW_NONE)
 		{
+			ToolbarParameters toolbar;
+
+			clearlooks_set_toolbar_parameters (&toolbar, widget, window, x, y);
+
 			cairo_save (cr);
-			STYLE_FUNCTION(draw_toolbar) (cr, colors, &params, x, y, width, height);
+			STYLE_FUNCTION(draw_toolbar) (cr, colors, &params, &toolbar, x, y, width, height);
 			cairo_restore (cr);
 		}
 		
@@ -460,6 +561,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		else
 		{
 			params.corners    = CR_CORNER_ALL;
+			/* if (!(ge_is_combo_box (widget, FALSE))) */
 			params.enable_glow = TRUE;
 		}		
 	
@@ -678,6 +780,8 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		GtkBorder indicator_spacing;
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		
+		params.enable_glow = TRUE;
 
 		ge_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
 		
@@ -734,9 +838,15 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	}
 	else if (DETAIL ("toolbar") || DETAIL ("handlebox_bin") || DETAIL ("dockitem_bin"))
 	{
+		WidgetParameters  params;
+		ToolbarParameters toolbar;
+
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		clearlooks_set_toolbar_parameters (&toolbar, widget, window, x, y);
+
 		/* Only draw the shadows on horizontal toolbars */
 		if (shadow_type != GTK_SHADOW_NONE && height < 2*width )
-			STYLE_FUNCTION(draw_toolbar) (cr, colors, NULL, x, y, width, height);
+			STYLE_FUNCTION(draw_toolbar) (cr, colors, &params, &toolbar, x, y, width, height);
 	}
 	else if (DETAIL ("trough"))
 	{
@@ -800,17 +910,21 @@ clearlooks_style_draw_slider (DRAW_ARGS, GtkOrientation orientation)
 		scrollbar.horizontal = (orientation == GTK_ORIENTATION_HORIZONTAL);
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
 
-		if (clearlooks_style->style == CL_STYLE_GLOSSY) /* XXX! */
-		{
-			scrollbar.color = colors->bg[CL_STATE_NORMAL];
-			ge_shade_color (&scrollbar.color, 0.5, &scrollbar.color);
+		if (clearlooks_style->colorize_scrollbar) {
+			scrollbar.color = colors->spot[1];
 			scrollbar.has_color = TRUE;
 		}
-		else if (clearlooks_style->has_scrollbar_color)
+
+		/* Set scrollbar color */
+		if (clearlooks_style->has_scrollbar_color)
 		{
 			ge_gdk_color_to_cairo (&clearlooks_style->scrollbar_color, &scrollbar.color);
 			scrollbar.has_color = TRUE;
 		}
+
+		if ((clearlooks_style->style == CL_STYLE_GLOSSY || clearlooks_style->style == CL_STYLE_GUMMY)
+			&& !scrollbar.has_color)
+			scrollbar.color = colors->bg[0];
 		
 		STYLE_FUNCTION(draw_scrollbar_slider) (cr, colors, &params, &scrollbar,
 		                                       x, y, width, height);
@@ -831,11 +945,11 @@ clearlooks_style_draw_option (DRAW_ARGS)
 	const ClearlooksColors *colors;
 	WidgetParameters params;
 	CheckboxParameters checkbox;
+	cairo_t *cr;
 	
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	cairo_t *cr;
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	colors = &clearlooks_style->colors;
 	
@@ -899,7 +1013,7 @@ clearlooks_style_draw_vline                      (GtkStyle               *style,
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
-	STYLE_FUNCTION(draw_separator) (cr, colors, NULL, &separator,
+	STYLE_FUNCTION(draw_separator) (cr, &colors->shade[3], NULL, &separator,
 	                           x, y1, 2, y2-y1);
 	
 	cairo_destroy (cr);
@@ -929,7 +1043,7 @@ clearlooks_style_draw_hline                      (GtkStyle               *style,
 	
 	separator.horizontal = TRUE;
 	
-	STYLE_FUNCTION(draw_separator) (cr, colors, NULL, &separator,
+	STYLE_FUNCTION(draw_separator) (cr, &colors->shade[3], NULL, &separator,
 	                           x1, y, x2-x1, 2);
 	
 	cairo_destroy (cr);
@@ -960,11 +1074,11 @@ clearlooks_style_draw_shadow_gap (DRAW_ARGS,
 		frame.gap_side  = gap_side;
 		frame.gap_x     = gap_x;
 		frame.gap_width = gap_width;
-		frame.border    = (CairoColor*)&colors->shade[5];
+		frame.border    = &colors->shade[5];
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
-		params.corners = CR_CORNER_NONE;
+		params.corners = CR_CORNER_ALL;
 		
 		STYLE_FUNCTION(draw_frame) (cr, colors, &params, &frame,
 		                       x, y, width, height);
@@ -1105,6 +1219,7 @@ clearlooks_style_init_from_rc (GtkStyle * style,
 	
 	clearlooks_style->menubarstyle      = CLEARLOOKS_RC_STYLE (rc_style)->menubarstyle;
 	clearlooks_style->has_scrollbar_color = CLEARLOOKS_RC_STYLE (rc_style)->flags & CL_FLAG_SCROLLBAR_COLOR;
+	clearlooks_style->colorize_scrollbar = CLEARLOOKS_RC_STYLE (rc_style)->colorize_scrollbar;
 	clearlooks_style->animation         = CLEARLOOKS_RC_STYLE (rc_style)->animation;
 	clearlooks_style->radius            = CLAMP (CLEARLOOKS_RC_STYLE (rc_style)->radius, 0.0, 10.0);
 
@@ -1149,20 +1264,6 @@ clearlooks_style_realize (GtkStyle * style)
 	}
 }
 
-static void
-gdk_cairo_set_source_color_alpha (cairo_t  *cr,
-                GdkColor *color, float alpha)
-{
-  g_return_if_fail (cr != NULL);
-  g_return_if_fail (color != NULL);
-
-  cairo_set_source_rgba (cr,
-            color->red / 65535.,
-            color->green / 65535.,
-            color->blue / 65535.,
-	        alpha);
-}
-
 static void
 clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType state_type,
             GdkRectangle *area, GtkWidget *widget, const gchar *detail,
@@ -1202,8 +1303,8 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 	else if (detail && !strcmp (detail, "colorwheel_dark"))
 		cairo_set_source_rgb (cr, 1., 1., 1.);
 	else
-		gdk_cairo_set_source_color_alpha (cr, &style->fg[state_type],
-						  0.7);
+		ge_cairo_set_gdk_color_with_alpha (cr, &style->fg[state_type],
+						       0.7);
 
 	cairo_set_line_width (cr, line_width);
 
@@ -1261,6 +1362,7 @@ clearlooks_style_copy (GtkStyle * style, GtkStyle * src)
 	cl_style->menubarstyle        = cl_src->menubarstyle;
 	cl_style->scrollbar_color     = cl_src->scrollbar_color;
 	cl_style->has_scrollbar_color = cl_src->has_scrollbar_color;
+	cl_style->colorize_scrollbar  = cl_src->colorize_scrollbar;
 	cl_style->animation           = cl_src->animation;
 	cl_style->radius              = cl_src->radius;
 	cl_style->style               = cl_src->style;
@@ -1323,6 +1425,53 @@ scale_or_ref (GdkPixbuf *src,
 	}
 }
 
+static void
+clearlooks_style_draw_layout (GtkStyle * style,
+	     GdkWindow * window,
+	     GtkStateType state_type,
+	     gboolean use_text,
+	     GdkRectangle * area,
+	     GtkWidget * widget,
+	     const gchar * detail, gint x, gint y, PangoLayout * layout)
+{
+  GdkGC *gc;
+
+  g_return_if_fail (GTK_IS_STYLE (style));
+  g_return_if_fail (window != NULL);
+
+  gc = use_text ? style->text_gc[state_type] : style->fg_gc[state_type];
+
+  if (area)
+    gdk_gc_set_clip_rectangle (gc, area);
+
+  if (state_type == GTK_STATE_INSENSITIVE) {
+    ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+    ClearlooksColors *colors = &clearlooks_style->colors;
+
+    WidgetParameters params;
+    GdkColor etched;
+    CairoColor temp;
+
+    clearlooks_set_widget_parameters (widget, style, state_type, &params);
+
+    if (GTK_WIDGET_NO_WINDOW (widget))
+      ge_shade_color (&params.parentbg, 1.2, &temp);
+    else
+      ge_shade_color (&colors->bg[widget->state], 1.2, &temp);
+    etched.red = (int) (temp.r * 65535);
+    etched.green = (int) (temp.g * 65535);
+    etched.blue = (int) (temp.b * 65535);
+
+    gdk_draw_layout_with_colors (window, style->text_gc[state_type], x + 1, y + 1, layout, &etched, NULL);
+    gdk_draw_layout (window, style->text_gc[state_type], x, y, layout);
+  }
+  else
+    gdk_draw_layout (window, gc, x, y, layout);
+
+  if (area)
+    gdk_gc_set_clip_rectangle (gc, NULL);
+}
+
 static GdkPixbuf *
 clearlooks_style_draw_render_icon (GtkStyle            *style,
              const GtkIconSource *source,
@@ -1433,6 +1582,7 @@ clearlooks_style_class_init (ClearlooksStyleClass * klass)
 	style_class->draw_resize_grip = clearlooks_style_draw_resize_grip;
 	style_class->draw_tab         = clearlooks_style_draw_tab;
 	style_class->draw_arrow       = clearlooks_style_draw_arrow;
+	style_class->draw_layout      = clearlooks_style_draw_layout;
 	style_class->render_icon      = clearlooks_style_draw_render_icon;
 
 	clearlooks_register_style_classic (&clearlooks_style_class->style_functions[CL_STYLE_CLASSIC]);
@@ -1440,6 +1590,8 @@ clearlooks_style_class_init (ClearlooksStyleClass * klass)
 	clearlooks_register_style_glossy (&clearlooks_style_class->style_functions[CL_STYLE_GLOSSY]);
 	clearlooks_style_class->style_functions[CL_STYLE_INVERTED] = clearlooks_style_class->style_functions[CL_STYLE_CLASSIC];
 	clearlooks_register_style_inverted (&clearlooks_style_class->style_functions[CL_STYLE_INVERTED]);
+	clearlooks_style_class->style_functions[CL_STYLE_GUMMY] = clearlooks_style_class->style_functions[CL_STYLE_CLASSIC];
+	clearlooks_register_style_gummy (&clearlooks_style_class->style_functions[CL_STYLE_GUMMY]);
 }
 
 GType clearlooks_type_style = 0;
